@@ -62,8 +62,19 @@ def read_dotenv(filename: str) -> dict[str, str]:
         # remove quotes (not sure if this is standard behaviour)
         if len(value) >= 2 and value[0] == value[-1] == '"':
             value = value[1:-1]
-            # escape escape characters
-            value = bytes(value, "utf-8").decode("unicode-escape")
+            # un-escape escape characters
+            control_chars = {
+                r'\a': '\a',
+                r'\b': '\b',
+                r'\f': '\f',
+                r'\n': '\n',
+                r'\r': '\r',
+                r'\t': '\t',
+                r'\v': '\v',
+                r'\\': '\\',
+            }
+            for char, repl in control_chars.items():
+                value = value.replace(char, repl)
 
         elif len(value) >= 2 and value[0] == value[-1] == "'":
             value = value[1:-1]
